﻿#region Using Directives

using System.Collections.Generic;
using System.ServiceModel;
using HIPS.CommonSchemas;
using HIPS.CommonSchemas.PatientIdentifier;
using HIPS.PcehrDataStore.Schemas.Enumerators;
using HIPS.PcehrSchemas;

#endregion Using Directives

namespace HIPS.ServiceContracts.ServiceInterfaces
{
    /// <summary>
    /// Web service interface for the Assisted Registration service.
    /// Allows the fast and easy registration of patients to the National Digital Health Record System.
    /// </summary>
    [WCFExtras.Wsdl.Documentation.XmlComments]
    [ServiceContract(Namespace = "http://schemas.HIPS/Services/2012/01", Name = "IAssistedRegistrationService")]
    public interface IAssistedRegistrationService
    {
        /// <summary>
        /// Lists the current patients stored in the local PCEHR Data Store without a Digital Health Record.
        /// </summary>
        /// <param name="hospitalCodeSystem">The hospital code system.</param>
        /// <param name="hospitalCode">The hospital code.</param>
        /// <returns>List of patients without a PCEHR</returns>
        [OperationContract]
        PatientWithoutPcehrResponse ListPatientsWithoutPcehr(string hospitalCodeSystem, string hospitalCode = null);

        /// <summary>
        /// Registers the dependant for a Digital Health Record with the PCEHR Service.
        /// </summary>
        /// <param name="patientIdentifier">Patient identifier (Hospital-level MRN, State Patient ID, Validated IHI or PCEHR Data Store PatientMasterId)</param>
        /// <param name="representativeDemographics">The representative demographics.</param>
        /// <param name="identityType">Type of the identity.</param>
        /// <param name="indigenousStatus">The indigenous status.</param>
        /// <param name="documentConsent">The document consent.</param>
        /// <param name="correspondenceChannel">The correspondence channel.</param>
        /// <param name="acceptedTermsAndConditions">Whether the user accepted the terms and conditions.</param>
        /// <param name="representativeDeclaration">Whether the user accepted the representative declaration.</param>
        /// <param name="user">Information to identify the person responsible for this action.</param>
        /// <param name="consentForm">The consent form.</param>
        /// <returns>PCEHR Registration Response object.</returns>
        [OperationContract]
        PcehrRegistrationResponse RegisterDependant(PatientIdentifierBase patientIdentifier, Demographic representativeDemographics, EvidenceOfIdentityType identityType, IndigenousStatus indigenousStatus, List<RegistrationDocumentConsent> documentConsent, RegistrationCorrespondenceChannel correspondenceChannel, bool acceptedTermsAndConditions, bool representativeDeclaration, UserDetails user, Attachment consentForm = null);

        /// <summary>
        /// Registers the patient for a Digital Health Record with the PCEHR Service.
        /// </summary>
        /// <param name="patientIdentifier">Patient identifier (Hospital-level MRN, State Patient ID, Validated IHI or PCEHR Data Store PatientMasterId)</param>
        /// <param name="identityType">Type of the identity.</param>
        /// <param name="indigenousStatus">The indigenous status.</param>
        /// <param name="documentConsent">The document consent.</param>
        /// <param name="correspondenceChannel">The correspondence channel.</param>
        /// <param name="acceptedTermsAndConditions">if set to <c>true</c> [accepted terms and conditions].</param>
        /// <param name="user">Information to identify the person responsible for this action.</param>
        /// <param name="consentForm">The consent form.</param>
        /// <returns>PCEHR Registration Response object.</returns>
        [OperationContract]
        PcehrRegistrationResponse RegisterPatient(PatientIdentifierBase patientIdentifier, EvidenceOfIdentityType identityType, IndigenousStatus indigenousStatus, List<RegistrationDocumentConsent> documentConsent, RegistrationCorrespondenceChannel correspondenceChannel, bool acceptedTermsAndConditions, UserDetails user, Attachment consentForm = null);

        /// <summary>
        /// Reregisters the dependant for a Digital Health Record with the PCEHR Service.
        /// </summary>
        /// <param name="patientMasterId">The patient master identifier.</param>
        /// <param name="patientIdentifier">Patient identifier (Hospital-level MRN, State Patient ID, Validated IHI or PCEHR Data Store PatientMasterId)</param>
        /// <param name="representativeDemographics">The representative demographics.</param>
        /// <param name="identityType">Type of the identity.</param>
        /// <param name="indigenousStatus">The indigenous status.</param>
        /// <param name="documentConsent">The document consent.</param>
        /// <param name="correspondenceChannel">The correspondence channel.</param>
        /// <param name="acceptedTermsAndConditions">Whether the user accepted the terms and conditions.</param>
        /// <param name="representativeDeclaration">Whether the user accepted the representative declaration.</param>
        /// <param name="user">Information to identify the person responsible for this action.</param>
        /// <param name="consentForm">The consent form.</param>
        /// <returns>PCEHR Registration Response object.</returns>
        [OperationContract]
        PcehrRegistrationResponse ReregisterDependant(int patientMasterId, PatientIdentifierBase patientIdentifier, Demographic representativeDemographics, EvidenceOfIdentityType identityType, IndigenousStatus indigenousStatus, List<RegistrationDocumentConsent> documentConsent, RegistrationCorrespondenceChannel correspondenceChannel, bool acceptedTermsAndConditions, bool representativeDeclaration, UserDetails user, Attachment consentForm = null);

        /// <summary>
        /// Reregisters the patient for a Digital Health Record with the PCEHR Service.
        /// </summary>
        /// <param name="patientMasterId">The patient master identifier.</param>
        /// <param name="patientIdentifier">Patient identifier (Hospital-level MRN, State Patient ID, Validated IHI or PCEHR Data Store PatientMasterId)</param>
        /// <param name="identityType">Type of the identity.</param>
        /// <param name="indigenousStatus">The indigenous status.</param>
        /// <param name="documentConsent">The document consent.</param>
        /// <param name="correspondenceChannel">The correspondence channel.</param>
        /// <param name="acceptedTermsAndConditions">if set to <c>true</c> [accepted terms and conditions].</param>
        /// <param name="user">Information to identify the person responsible for this action.</param>
        /// <param name="consentForm">The consent form.</param>
        /// <returns>PCEHR Registration Response object.</returns>
        [OperationContract]
        PcehrRegistrationResponse ReregisterPatient(int patientMasterId, PatientIdentifierBase patientIdentifier, EvidenceOfIdentityType identityType, IndigenousStatus indigenousStatus, List<RegistrationDocumentConsent> documentConsent, RegistrationCorrespondenceChannel correspondenceChannel, bool acceptedTermsAndConditions, UserDetails user, Attachment consentForm = null);
    }
}